@@ -86,7 +86,12 @@ from typing import Any, Iterator, List, Optional, Sequence, Union, overload
 
 # 3rd party
 import numpy  # type: ignore
+import pandas  # type: ignore
 from domdf_python_tools.doctools import prettify_docstrings
+from domdf_python_tools.typing import PathLike
+from pandas import DataFrame
+
+pandas.DataFrame.__module__ = "Pandas"
 
 __all__ = [
 		"intdiv",
@@ -113,6 +118,7 @@ __all__ = [
 		"log_factorial",
 		"equiv_operators",
 		"FRange",
+		"concatenate_csv",
 		]
 
 
@@ -398,23 +404,9 @@ def lcm(numbers: Sequence[int]) -> float:
 		return product
 
 
-def hcf(a: int, b: int) -> int:
-	"""
+hcf = gcd
 
-	:param a:
-	:param b:
-	"""
-
-	return gcd(a, b)
-
-
-def hcf2(numbers: Sequence[int]) -> int:
-	"""
-
-	:param numbers:
-	"""
-
-	return gcd2(numbers)
+hcf2 = gcd2
 
 
 def mod_inverse(a: int, m: int) -> Optional[float]:
@@ -741,3 +733,31 @@ class FRange(Sequence[float]):
 
 	def __hash__(self):
 		return hash(tuple(self))
+
+
+def concatenate_csv(*files: PathLike, outfile: Optional[PathLike] = None) -> DataFrame:
+	r"""
+	Concatenate multiple CSV files together and return a :class:`pandas.DataFrame` representing the output.
+
+	:param \*files: The files to concatenate.
+	:param outfile: The file to save the output as. If :py:obj:`None` no file will be saved.
+
+	:return: A :class:`pandas.DataFrame` containing the concatenated CSV data
+
+	.. versionadded:: 0.3.0
+	"""
+
+	data_frames = []
+
+	for csv_file in files:
+		# Read CSV file to data frame
+		results_df = pandas.read_csv(csv_file, header=0, index_col=False, dtype=str)
+
+		data_frames.append(results_df)
+
+	concat_df = pandas.concat(data_frames)
+
+	if outfile is not None:
+		concat_df.to_csv(outfile, index=False)
+
+	return concat_df
